@@ -1,5 +1,9 @@
-#!/usr/bin/env python
-""":mod:`primpy.solver`: general setup for running :func:`scipy.integrate.solve_ivp`."""
+"""General setup for running :func:`scipy.integrate.solve_ivp`.
+
+(Modified from "primordial" by Will Handley.)
+"""
+
+
 import numpy as np
 from scipy import integrate
 
@@ -12,20 +16,16 @@ def solve(ic, *args, **kwargs):
 
     Parameters
     ----------
-        ic : primordial.initialconditions.InitialConditions
-            Initial conditions specifying relevant equations, variables, and
-            initial numerical values.
-
-    All other arguments are identical to :func:`scipy.integrate.solve_ivp`.
+    ic : :class:`primpy.initialconditions.InitialConditions`
+        Initial conditions specifying relevant equations, variables, and
+        initial numerical values.
+    *args, **kwargs
+        All other arguments are identical to :func:`scipy.integrate.solve_ivp`.
 
     Returns
     -------
-        sol : Bunch object
-            Solution to the inverse value problem.
-            Monkey-patched version of the Bunch type usually returned by
-            :func:`scipy.integrate.solve_ivp`.
-
-    `(c)` modified from "primordial" by Will Handley.
+    sol : Bunch object same as returned by :func:`scipy.integrate.solve_ivp`
+        Solution to the inverse value problem.
 
     """
     events = kwargs.pop('events', [])
